<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/**
 * Abstraction for database fields.
 * This class is an abstraction layer for SQL columns in HTML
 */
class Field {
	
	private $name;
	private $label;
	private $value;
	private $type;
	private $width;
	private $html;
	
	/**
	 * Class constructor.
	 * Initialize the class.
	 * @param name The name of the field.
	 * @param label The label the field will have in HTML.
	 * @param type The HTML type of the field (text, combobox, textarea).
	 * @param value The current value of the field.
	 * @param width The width of the field when generating HTML output.
	 */
	public function Field($name, $label, $type, $value, $width) {
		$this->setName($name);
		$this->setLabel($label);
		$this->setType($type);
		$this->setValue($value);
		$this->setWidth($width);
	}
	
	/**
	 * Get the field name.
	 * This function returns the field name.
	 * @return The field name.
	 */
	public function getName() {
		return $this->name;
	}
	
	/**
	 * Get the field label.
	 * This function returns the field label.
	 * @return The field label.
	 */
	public function getLabel() {
		return $this->label;
	}
	
	/**
	 * Get the field type.
	 * This function returns the field type.
	 * @return The field type.
	 */
	public function getType() {
		return $this->type;
	}
	
	/**
	 * Get the field value.
	 * This function returns the field value.
	 * @return The field value.
	 */
	public function getValue() {
		return $this->value;
	}
	
	/**
	 * Get the field width.
	 * This function returns the field width.
	 * @return The field width.
	 */
	public function getWidth() {
		return $this->width;
	}
	
	/**
	 * Set the field name.
	 * This function sets the field name.
	 * @param The new field name.
	 */
	public function setName($name) {
		$this->name = $name;
	}
	
	/**
	 * Set the field label.
	 * This function sets the field label.
	 * @param The new field label.
	 */
	public function setLabel($label) {
		$this->label = $label;
	}
	
	/**
	 * Set the field type.
	 * This function sets the field type.
	 * @param The new field type.
	 */
	public function setType($type) {
		$this->type = $type;
	}
	
	/**
	 * Set the field value.
	 * This function sets the field value.
	 * @param The new field value.
	 */
	public function setValue($value) {
		$this->value = trim($value);
	}
	
	/**
	 * Set the field width.
	 * This function sets the field width.
	 * @param The new field width.
	 */
	public function setWidth($width) {
		$this->width = $width;
	}
	
	/**
	 * Set the HTML output of the field.
	 * This will set a fixed HTML output for the field, regardless of it's value and type.
	 * @param html The HTML formatted text for the field.
	 */
	public function setHTML($html) {
		$this->html = $html;
	}
	
	/**
	 * Output the system as an HTML form.
	 * This function will output the system as an HTML form.
	 */
	public function html() {

		/* If the field has its HTML field set, return that instead. */
		if(!empty($this->html))
			return $this->html;

		/* Otherwise we return HTML formatted text as following. */	
		if($this->type == "text")
			return "<input name=\"" . $this->name . "\" type=\"text\" value=\"" . Util::makeFormSafe($this->value) . "\" size=\"" . $this->width . "\">";

		if($this->type == "textarea")
			return "<textarea name=\"" . $this->name . "\" cols=\"40\" rows=\"" . $this->width . "\">" . Util::makeFormSafe($this->value) . "</textarea>";

		return "?";	
	}
}
?>
