<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include required classes */
include_once("include/Table.class.php");
include_once("include/Util.class.php");
include_once("include/DynamicList.class.php");

/**
 * Class which builds HTML list of groups.
 * This class can generate a dynamic list of groups in an HTML form.
 * @see DynamicList
 */
class GroupList extends DynamicList {
	
	/** The empty list message. */
	public $emptyListMessage     = "There are no groups to display.";
	/** The already existing message */
	public $alreadyExistsMessage = "Sorry, that group already exists. Please choose a different groupname.";
	
	/**
	 * Class constructor.
	 * The class constructor.
	 * @see DynamicList
	 */
	public function GroupList() {
		parent::__construct("group", "Group");
	}
	
	/**
	 * Fill in the list using the database.
	 * This function is responsible for filling in the list using data from the database.
	 * @return boolean indicating success or failure.
	 * @see Database
	 */
	public function fillWithDatabase() {
		$result = Database::query("SELECT id, name FROM `group` ORDER BY name");
		
		while($row = mysql_fetch_array($result)) {
			parent::addItem("group" . $row['id'], $row['name']);
		}
	}

	/**
	 * Check if a group exists.
	 * This function returns boolean true if a group exists.
	 * @param groupId The group ID to search for.
	 * @param groupname The groupname to search for.
	 * @return Boolean true if the group exists.
	 */
	public function databaseItemExists($groupId, $groupname) {

		$result = array();
	
		/* Do we have groupId and groupname? Then look for other groupId's than our own ($groupId), who have $groupname */
		if($groupId != null && $groupname != null)
			$result = Database::queryToArray("SELECT id FROM `group` WHERE id!='" . Util::makeSqlSafe($groupId) . "' AND name='" . Util::makeSqlSafe($groupname) . "'");
		
		/* Do we have a groupId only? Then return the groupname for the given groupId */
		else if($groupId != null && $groupname == null)
			$result = Database::queryToArray("SELECT name FROM `group` WHERE id='" . Util::makeSqlSafe($groupId) . "'");
	
		/* Do we have a groupname only? Then return the id for the given groupname */
		else
			$result = Database::queryToArray("SELECT id FROM `group` WHERE name='" . Util::makeSqlSafe($groupname) . "'");
		
		/* Do we have a match? */
		if(count($result) > 0)
			return $result[0];
		else
			return null;
	}

	/**
	 * Insert a new group.
	 * This function will insert a new group in the database.
	 */
	public function databaseInsertItem($name) {
		if($name == "All groups")
			Output::htmlError("Sorry, you cannot name a group &quot;All groups&quot;. Please choose a different group name.",
				"Error", "index.php?page=GroupPage", "Back to Manage Groups");
		else
			Database::query("INSERT INTO `group` (name) VALUES ('" . Util::makeSqlSafe($name) . "')");
	}

	/**
	 * Update an existing group.
	 * This function will update an existing group in the database.
	 * @param groupId The groupId of the group.
	 * @param newName The new name of the group.
	 */	
	public function databaseUpdateItem($groupId, $newName) {
		Database::query("UPDATE `group` SET name='" . Util::makeSqlSafe($newName) . "' WHERE id='" . Util::makeSqlSafe($groupId) . "'");
	}
	
	/**
	 * Delete an existing group.
	 * This function is responsible for removing a group from the database.
	 * @param name The name of the group.
	 */
	public function databaseDeleteItemsExcluding($idArray) {

		/* Reset the $_POST array pointer */
		reset($_POST);

		/* loop all given groups in $_POST, to see if there is a default group */
		while(list($key, $value) = each($_POST)) {
			if(!empty($_POST['defaultgroup']) && $_POST['defaultgroup'] == $key) {
				$defaultGroupName = $value;
			}
		}

		/* Is the default group set? */
		if(empty($defaultGroupName)) {
			Output::htmlError("You must define a default group. Please choose a default group.", "Error", false);
			return;
		}
		
		/* Get the list of submitted groups */
		$submittedList      = Util::arrayToCommaList($idArray);

		/* Get a list of groups currently in the database */
		$currentGroupResult = Database::query("SELECT id FROM `group`");
		$currentGroupArray  = Database::resultToArray($currentGroupResult, 0);
		$currentGroupList   = Util::mysqlToCommaList($currentGroupResult);

		/* Check if there is at least one group left in the database */
		if(count($idArray) <= 0 || empty($submittedList) || count(array_intersect($currentGroupArray, $idArray)) <= 0) {
			Output::htmlError("Cannot delete more groups. There must be at least one group remaining.", "Error", false);
			return;
		
		/* Remove groups, and update systems */
		} else {
			Database::query("DELETE FROM `group` WHERE id NOT IN (" . $submittedList . ")");
		
			/* Update the default group */
			Database::query("UPDATE `group` SET isdefault=false WHERE name!='" . Util::makeSqlSafe($defaultGroupName) . "'");
			Database::query("UPDATE `group` SET isdefault=true  WHERE name='"  . Util::makeSqlSafe($defaultGroupName) . "'");
			Database::query("UPDATE system SET `group`=(SELECT id FROM `group` WHERE isdefault=true) WHERE `group` NOT IN (" . $submittedList . ")");
		}
	}
	
	
	/**
	 * Show the list of groups.
	 * This function overrides DynamicList::html(), because we also need radio buttons for the default group.
	 * @return HTML containing the list of groups.
	 * @see DynamicList
	 * @see Table
	 */
	public function html() {

		/* Find the default group */
		$defaultGroup = Util::makeFormSafe(Database::queryToArray("SELECT id FROM `group` WHERE isdefault=true LIMIT 1", false));

		/* Create a new HTML table */
		$table = new Table("500");
		$table->addColumn("Default Group");
		$table->addColumn($this->title, "*");
		$table->addColumn("");
		
		/* Reset the items array pointer */
		reset($this->items);
		
		/* Loop all items and output <input> for each */
		while(list($key, $value) = each($this->items)) {
			/* Is this the current default group? Set it checked if so */
			if(substr($key, 5) == $defaultGroup[0])
				$table->addRow("<input type=\"radio\"  name=\"defaultgroup\" value=\"" . Util::makeFormSafe($key) . "\" checked=\"checked\">");
			else
				$table->addRow("<input type=\"radio\"  name=\"defaultgroup\" value=\"" . Util::makeFormSafe($key) . "\">");
		
			/* Output the default dynamic list stuff */
			$table->addRow("<input type=\"text\"   name=\"" . Util::makeFormSafe($key) . "\" value=\"" . Util::makeFormSafe($value) . "\" size=\"40\">");
			$table->addRow("<input type=\"submit\" name=\"delete" . Util::makeFormSafe($key) . 
				"\" value=\"Delete\" onClick=\"return verifyDelete('" . Util::makeJavascriptSafe($value) . "')\">");
		}
		
		/* If the table is empty, inform the user */
		if($table->isEmpty()) {
			$table->addRow("");
			$table->addRow($this->emptyListMessage, "100", "center", "middle");
			$table->addRow("");
		}

		/* Add an empty line, and a create input field, to let the user add new groups */
		$table->addRow("");
		$table->addRow("<br><input type=\"text\"   name=\"newgroup\"    value=\"\" size=\"40\"><br><br>");
		$table->addRow("<br><input type=\"submit\" name=\"creategroup\" value=\"Create\"><br><br>");

		/* Return the final HTML table */
		return $table->html();
	}
}
?>
