<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/*
 * Make sure we are not directly invoked
 */
if(!defined("INDEX"))
	die();

/*
 * Output - a class used to abstract the actual HTML output flow
 */
class Output {

	private static $htmlHeader;
	private static $htmlTop;
	private static $htmlBody;
	private static $htmlFooter;
	private static $htmlError;

	/*
	 * htmlHeader - append HTML to the current HTML header
	 */
	public function htmlHeader($html) {
		Output::$htmlHeader .= $html;	
	}
	
	/*
	 * htmlBody - append HTML to the current HTML body
	 */
	public function htmlBody($html) {
		Output::$htmlBody .= $html;
	}
	
	/*
	 * htmlTop - append HTML to the current HTML top body (e.g. for the menu)
	 */
	public function htmlTop($html) {
		Output::$htmlTop .= $html;
	}
	
	/*
	 * htmlFooter - append HTML to the current HTML footer
	 */
	public function htmlFooter($html) {
		Output::$htmlFooter .= $html;
	}

	/*
	 * htmlError - outputs an error in a Table to $htmlErrors
	 */
	public static function htmlError($message, $errorCode = "Error", $backURL = "index.php?page=SystemOverviewPage", $backTitle="Back to System Overview") {
		/*
		 * If an url is specified to let the user return to, append it to the message.
		 */
		if($backURL) {
			$message .= "<br><br><center><a href=\"$backURL\">$backTitle</a></center>";
		}

		$errorTable = new Table("500");
		$errorTable->addColumn($errorCode);
		$errorTable->addRow("<br>" . $message . "<br><br>");
		
		Output::$htmlError .= "<br>" . $errorTable->html() . "<br><br>";
	}

	/**
	 * Uses a class, which implements Page, to output HTML.
	 * This function calls get() or post() in $class, to output HTML.
	 * @param class A class which implements Page.
	 * @see Page
	 */
	public static function page($class) {
		if($_SERVER['REQUEST_METHOD'] == "GET")
			$class->get();
		else if($_SERVER['REQUEST_METHOD'] == "POST")
			$class->post();
	}

	/*
	 * redirect - outputs a location: header to redirect the user to $url
	 */
	public static function redirect($url) {
		/*
		 * Only redirect if no errors are occured
		 */
		if(empty(Output::$htmlError)) {
			header("location: " . $url);
			return true;
		} else
			return false;
	}
	
	/**
	 * See if any error occurred.
	 * This will return true if we have any errors.
	 * @return Boolean true if errors have occurred ($htmlError is not empty).
	 */
	public static function haveErrors() {
		return empty(Output::$htmlError) ? false : true;
	}
	
	/*
	 * flush - actually outputs the internal buffers using echo() and resets all to zero
	 */
	public function flush() {
	
		/* Output current buffers */
		
		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n";
		echo "<html>\n";
		echo "<head>\n";
		echo Output::$htmlHeader;
		echo "</head>\n";
		echo "<body>\n";
		echo Output::$htmlTop;
		echo Output::$htmlError;
		echo Output::$htmlBody;
		echo Output::$htmlFooter;
		echo "</body>\n";
		echo "</html>\n";
		
		/* Reset buffers */
		Output::$htmlHeader = 0;
		Output::$htmlTop = 0;
		Output::$htmlError = 0;
		Output::$htmlBody = 0;
		Output::$htmlFooter = 0;
	}
}
?>
