<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include required classes */
include_once("include/Table.class.php");
include_once("include/Util.class.php");
include_once("include/DynamicList.class.php");

/**
 * Class which builds HTML speciallists.
 * This class can generate dynamic speciallists in an HTML form.
 * @see DynamicList
 */
class SpecialList extends DynamicList {
	
	/** The empty list message. */
	public $emptyListMessage     = "There are no specialities to display.";
	/** The already existing message */
	public $alreadyExistsMessage = "Sorry, that speciality already exists. Please choose a different name.";
	
	/**
	 * Class constructor.
	 * The class constructor.
	 * @see DynamicList
	 */
	public function SpecialList() {
		parent::__construct("special", "Speciality");
	}
	
	/**
	 * Fill in the list using the database.
	 * This function is responsible for filling in the list using data from the database.
	 * @return boolean indicating success or failure.
	 * @see Database
	 */
	public function fillWithDatabase() {
		$result = Database::query("SELECT id, name FROM special ORDER BY name");
		
		while($row = mysql_fetch_array($result)) {
			parent::addItem("special" . $row['id'], $row['name']);
		}
	}

	/**
	 * Check if a speciality exists.
	 * This function returns boolean true if a speciality exists.
	 * @param specialId The speciality ID to search for.
	 * @param name The name of the speciality to search for.
	 * @return Boolean true if the speciality exists.
	 */
	public function databaseItemExists($specialId, $name) {

		$result = array();
	
		/* Do we have specialId and name? Then look for other specialId's than our own ($specialId), who have $name */
		if($specialId != null && $name != null)
			$result = Database::queryToArray("SELECT id FROM special WHERE id!='" . Util::makeSqlSafe($specialId) . "' AND name='" . Util::makeSqlSafe($name) . "'");
		
		/* Do we have a specialId only? Then return the name for the given specialId */
		else if($specialId != null && $name == null)
			$result = Database::queryToArray("SELECT name FROM special WHERE id='" . Util::makeSqlSafe($specialId) . "'");
	
		/* Do we have a specialId only? Then return the id for the given name */
		else
			$result = Database::queryToArray("SELECT id FROM special WHERE name='" . Util::makeSqlSafe($name) . "'");
		
		/* Do we have a match? */
		if(count($result) > 0)
			return $result[0];
		else
			return null;
	}

	/**
	 * Insert a new speciality.
	 * This function will insert a new speciality in the database.
	 */
	public function databaseInsertItem($name) {
		Database::query("INSERT INTO special (name) VALUES ('" . Util::makeSqlSafe($name) . "')");
	}

	/**
	 * Update an existing speciality.
	 * This function will update an existing speciality in the database.
	 * @param specialId The specialId of the speciality.
	 * @param newName The new name of the speciality.
	 */	
	public function databaseUpdateItem($specialId, $newName) {
		Database::query("UPDATE special SET name='" . Util::makeSqlSafe($newName) . "' WHERE id='" . Util::makeSqlSafe($specialId) . "'");
	}
	
	/**
	 * Delete an existing speciality.
	 * This function is responsible for removing an speciality from the database.
	 * @param name The name of the speciality.
	 */
	public function databaseDeleteItemsExcluding($idArray) {
		$in = Util::arrayToCommaList($idArray);
		Database::query("UPDATE system SET special=NULL WHERE special NOT IN (" . $in . ")");
		Database::query("DELETE FROM special WHERE id NOT IN (" . $in . ")");
	}
}
?>
