<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/*
 * Make sure we are not directly invoked
 */
if(!defined("INDEX"))
	die();

/*
 * We need both Column and Entry classes
 */
include_once("include/Column.class.php");
include_once("include/Row.class.php");

/*
 * Table - a class used to abstract drawing of HTML tables
 */
class Table {
	
	private $width;
	private $align;
	private $cssClass;
	private $outputColumnHeaders;
	
	private $columns = array();
	private $totalColumns = 0;
	
	private $rows = array();
	private $totalRows = 0;
	
	private $title;
	
	/*
	 * Table - the class constructor
	 */
	public function Table($width = "100%", $align = "center", $cssClass = "normaltable", $outputColumnHeaders = true) {
		$this->width = $width;
		$this->align = $align;
		$this->cssClass = $cssClass;
		$this->outputColumnHeaders = $outputColumnHeaders;
	}
	
	/*
	 * setTitle - sets a title for this table
	 */
	public function setTitle($title) {
		$this->title = $title;
	}

	/*
	 * addColumn - adds a column to this table
	 */
	public function addColumn($title = "Column", $width = "*", $height = "40", $align = "center", $cssClass = "normalcolumn") {
		$this->columns[$this->totalColumns++] = new Column($title, $width, $height, $align, $cssClass);
	}
	
	/*
	 * addRow - adds a row to this table
	 */
	public function addRow($content, $height = "30", $align = "center", $valign = "middle", $colspan = "1", $rowspan = "1", $cssClass = "normalrow") {
		$this->rows[$this->totalRows++] = new Row($content, $height, $align, $valign, $colspan, $rowspan, $cssClass);
	}
	
	/*
	 * isEmpty - returns true if this table is empty (i.e. no rows)
	 */
	public function isEmpty() {
		return count($this->rows) <= 0 ? true : false;
	}
	
	/*
	 * columnCount - returns the total columns in this table
	 */
	public function columnCount() {
		return $this->totalColumns;
	}
	
	/*
	 * rowCount - returns the total rows in this table
	 */
	public function rowCount() {
		return $this->totalRows;
	}

	/*
	 * html - outputs this table in HTML
	 */
	public function html() {
		/*
		 * Output the initial <table> tag
		 */
		$html = "<table width=\"$this->width\" align=\"$this->align\" class=\"$this->cssClass\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\n";

		/*
		 * If the table has a title set, output it
		 */
		if($this->title)
			$html .= "<tr><td colspan=\"" . count($this->columns) . "\" height=\"40\" align=\"center\" class=\"normalcolumn\">" . $this->title . "</td></tr>";

		/*
		 * Output the column headers, if $outputColumnHeaders is set to true
		 */
		if($this->outputColumnHeaders) {
			$html .= "<tr>\n";
		 
			for($i = 0; $i < count($this->columns); $i++)
				$html .= $this->columns[$i]->html();

			$html .= "</tr>\n";
		}
		
		/*
		 * Then we output the rows
		 */
		for($i = 0; $i < count($this->rows); $i++) {
			/*
			 * Each time $i reaches a divisor of $this->columns, add a <tr>, and a </tr> if it's not the first run
			 */
			if($i % (count($this->columns)) == 0) {
				if($i != 0)
					$html .= "</tr>\n";

				$html .= "<tr class=\"" . $this->cssClass . "\">\n";
			}
			$html .= $this->rows[$i]->html();
		}
		/* only close the last row if there were any rows at all */
		if(count($this->rows) > 0)
			$html .= "</tr>\n";

		/*
		 * And close the <table> tag
		 */
		return $html . "</table>\n";
	}
}
?>
