<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include required classes */
include_once("include/Table.class.php");
include_once("include/Util.class.php");
include_once("include/DynamicList.class.php");

/**
 * Class which builds HTML userlists.
 * This class can generate dynamic userlists in an HTML form.
 * @see DynamicList
 */
class UserList extends DynamicList {
	
	/** The empty list message. */
	public $emptyListMessage     = "There are no users to display.";
	/** The already existing message */
	public $alreadyExistsMessage = "Sorry, that user already exists. Please choose a different username.";
	
	/**
	 * Class constructor.
	 * The class constructor.
	 * @see DynamicList
	 */
	public function UserList() {
		parent::__construct("user", "User");
	}
	
	/**
	 * Fill in the list using the database.
	 * This function is responsible for filling in the list using data from the database.
	 * @return boolean indicating success or failure.
	 * @see Database
	 */
	public function fillWithDatabase() {
		$result = Database::query("SELECT id, name FROM user ORDER BY name");
		
		while($row = mysql_fetch_array($result)) {
			parent::addItem("user" . $row['id'], $row['name']);
		}
	}

	/**
	 * Check if a user exists.
	 * This function returns boolean true if a user exists.
	 * @param userId The userID to search for.
	 * @param username The username to search for.
	 * @return Boolean true if the user exists.
	 */
	public function databaseItemExists($userId, $username) {

		$result = array();
	
		/* Do we have userId and username? Then look for other userId's than our own (userId), who have username */
		if($userId != null && $username != null)
			$result = Database::queryToArray("SELECT id FROM user WHERE id!='" . Util::makeSqlSafe($userId) . "' AND name='" . Util::makeSqlSafe($username) . "'");
		
		/* Do we have a userId only? Then return the username for the given userId */
		else if($userId != null && $username == null)
			$result = Database::queryToArray("SELECT name FROM user WHERE id='" . Util::makeSqlSafe($userId) . "'");
	
		/* Do we have a username only? Then return the id for the given username */
		else
			$result = Database::queryToArray("SELECT id FROM user WHERE name='" . Util::makeSqlSafe($username) . "'");
		
		/* Do we have a match? */
		if(count($result) > 0)
			return $result[0];
		else
			return null;
	}

	/**
	 * Insert a new user.
	 * This function will insert a new user in the database.
	 */
	public function databaseInsertItem($name) {
		Database::query("INSERT INTO user (name) VALUES ('" . Util::makeSqlSafe($name) . "')");
	}

	/**
	 * Update an existing user.
	 * This function will update an existing user in the database.
	 * @param userId The userId of the user.
	 * @param newName The new name of the user.
	 */	
	public function databaseUpdateItem($userId, $newName) {
		Database::query("UPDATE user SET name='" . Util::makeSqlSafe($newName) . "' WHERE id='" . Util::makeSqlSafe($userId) . "'");
	}
	
	/**
	 * Delete an existing user.
	 * This function is responsible for removing an user from the database.
	 * @param name The name of the user.
	 */
	public function databaseDeleteItemsExcluding($idArray) {
		$in = Util::arrayToCommaList($idArray);
		Database::query("UPDATE system SET user=NULL WHERE user NOT IN (" . $in . ")");
		Database::query("DELETE FROM user WHERE id NOT IN (" . $in . ")");
	}
}
?>
