<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/*
 * Make sure we are not directly invoked
 */
if(!defined("INDEX"))
	die();

/*
 * Util - a class used for common functions
 */

class Util {
	/*
	 * makeSqlSafe - escape all quotes
	 */
	public static function makeSqlSafe($input) {
		return mysql_real_escape_string($input);
	}

	/*
	 * makeFileSafe - filters out all non alphabetical charactars, for (partial) filenames
	 */
	public static function makeFileSafe($input) {
		return preg_replace('/[^a-z0-9_ ]/i','',$input);
	}
	
	/*
	 * arrayFormSafe - strips all slashes from a (multidimensional) array, and calls htmlspecialchars()
	 */
	public static function makeFormSafe($value) {
		
		$value = is_array($value) ?
			 array_map(array('Util', 'makeFormSafe'), $value) :
			 htmlspecialchars(stripslashes($value));

		return $value;
	}
	
	/*
	 * arrayJavascriptSafe - adds slashes to a (multidimensional) array, and calls htmlspecialchars(), and converts \r\n to <br>
	 */
	public static function makeJavascriptSafe($value) {
	
		$value = is_array($value) ?
			 array_map('Util', 'makeJavascriptSafe', $value) :
			 htmlspecialchars(addslashes(Util::stripNewLine(nl2br($value))));

		return $value;
	}
	
	/*
	 * stripNewLine - strips out all newline characters from a string
	 */
	public static function stripNewLine($string) {
		return str_replace("\n", "", str_replace("\r", "", $string));
	}
	
	/*
	 * getLine - returns line $num from $string
	 */
	public static function getLine($string, $num) {
		$lines = explode("\n", $string);
		return $lines[$num];
	}
	
	
	/*
	 * arrayFilterKeys - returns an array without associative keys (only index numbers)
	 */
	public static function arrayFilterKeys($array) {
		
		$filteredArray = array();
		$arrayKeys = array_keys($array);
		$num = 0;
		
		for($i = 0; $i < count($arrayKeys); $i++) {
			if(is_integer($arrayKeys[$i]))
				$filteredArray[$num++] = $array[$arrayKeys[$i]];
		}

		return $filteredArray;
	}
	
	/*
	 * arrayToCommaList - returns a comma separated list of $array
	 */
	public function arrayToCommaList($array, $safe = true) {
	
		$list = "";

		for($i = 0; $i < count($array); $i++) {

			if($safe)
				$list .= "'" . Util::makeSqlSafe($array[$i]) . "'";
			else
				$list .= "'" . $array[$i] . "'";
			
			if($i != (count($array) - 1))
				$list .= ", ";
		}
		return empty($list) ? "''" : $list;
	}
	
	/*
	 * mysqlToCommaList - returns a comma separated list of $mysqlResult
	 */
	public function mysqlToCommaList($mysqlResult, $safe = true) {
	
		$list = "";
		$num  = 0;
		mysql_data_seek($mysqlResult, 0);

		while($row = mysql_fetch_array($mysqlResult)) {

			if($safe)
				$list .= "'" . Util::makeSqlSafe($row[0]) . "'";
			else
				$list .= "'" . $row[0] . "'";
			
			if($num++ != (mysql_num_rows($mysqlResult) - 1))
				$list .= ", ";
		}
		return empty($list) ? "''" : $list;
	}
}
?>
