<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include required classes */
include_once("include/Table.class.php");
include_once("include/Util.class.php");
include_once("include/DynamicList.class.php");

/**
 * Class which builds HTML list of operating system versions.
 * This class can generate a dynamic list of operating system versions in an HTML form.
 * @see DynamicList
 * @see OS
 */
class VersionList extends DynamicList {
	
	/** The operating system id of which we create this version list */
	private $osId;
	/** The empty list message. */
	public $emptyListMessage     = "There are no versions to display.";
	/** The already existing message */
	public $alreadyExistsMessage = "Sorry, that version already exists. Please choose a different versionname.";
	
	/**
	 * Class constructor.
	 * The class constructor.
	 * @see DynamicList
	 */
	public function VersionList($osId) {
		parent::__construct("version", null, "375");
		$this->osId = intval($osId);
	}
	
	/**
	 * Fill in the list using the database.
	 * This function is responsible for filling in the list using data from the database.
	 * @return boolean indicating success or failure.
	 * @see Database
	 */
	public function fillWithDatabase() {
		$result = Database::query("SELECT id, name FROM `version` WHERE os='" . Util::makeSqlSafe($this->osId) . "' ORDER BY name");
		
		while($row = mysql_fetch_array($result)) {
			parent::addItem("version" . $row['id'], $row['name']);
		}
	}

	/**
	 * Check if a version exists.
	 * This function returns boolean true if a version exists.
	 * @param versionId The version ID to search for.
	 * @param versionname The versionname to search for.
	 * @return Boolean true if the version exists.
	 */
	public function databaseItemExists($versionId, $versionname) {

		$result = array();
	
		/* Do we have versionId and versionname? Then look for other versionId's than our own ($versionId), who have $versionname */
		if($versionId != null && $versionname != null)
			$result = Database::queryToArray("SELECT id FROM `version` WHERE id!='" . Util::makeSqlSafe($versionId) . 
				"' AND name='" . Util::makeSqlSafe($versionname) . "' AND os='" . Util::makeSqlSafe($this->osId) . "'");
		
		/* Do we have a versionId only? Then return the versionname for the given versionId */
		else if($versionId != null && $versionname == null)
			$result = Database::queryToArray("SELECT name FROM `version` WHERE id='" . Util::makeSqlSafe($versionId) .
				"' AND os='" . Util::makeSqlSafe($this->osId) . "'");
	
		/* Do we have a versionname only? Then return the id for the given versionname */
		else
			$result = Database::queryToArray("SELECT id FROM `version` WHERE name='" . Util::makeSqlSafe($versionname) .
				"' AND os='" . Util::makeSqlSafe($this->osId) . "'");
		
		/* Do we have a match? */
		if(count($result) > 0)
			return $result[0];
		else
			return null;
	}

	/**
	 * Insert a new version.
	 * This function will insert a new version in the database.
	 */
	public function databaseInsertItem($name) {
		Database::query("INSERT INTO `version` (name,os) VALUES ('" . Util::makeSqlSafe($name) . "','" . Util::makeSqlSafe($this->osId) . "')");
	}

	/**
	 * Update an existing version.
	 * This function will update an existing version in the database.
	 * @param versionId The versionId of the version.
	 * @param newName The new name of the version.
	 */	
	public function databaseUpdateItem($versionId, $newName) {
		Database::query("UPDATE `version` SET name='" . Util::makeSqlSafe($newName) . "' WHERE id='" . Util::makeSqlSafe($versionId) .
			"' AND os='" . Util::makeSqlSafe($this->osId) . "'");
	}
	
	/**
	 * Delete an existing version.
	 * This function is responsible for removing a version from the database.
	 * @param name The name of the version.
	 */
	public function databaseDeleteItemsExcluding($idArray) {

		/* We only delete versions if $osId != null */
		if($this->osId == null)
			return;

		/* Get the list of submitted versions */
		$submittedList      = Util::arrayToCommaList($idArray);

		/* Get a list of versions currently in the database */
		$currentversionResult = Database::query("SELECT id FROM `version` WHERE os='" . Util::makeSqlSafe($this->osId) . "'");
		$currentversionArray  = Database::resultToArray($currentversionResult, 0);
		$currentversionList   = Util::mysqlToCommaList($currentversionResult);

		/* Check if there is at least one version left in the database */
		if(count($idArray) <= 0 || empty($submittedList) || count(array_intersect($currentversionArray, $idArray)) <= 0) {
			Output::htmlError("Cannot delete more versions. There must be at least one version remaining.", "Error", false);
			return;
		
		/* Remove versions, and update systems */
		} else {
			Database::query("UPDATE system SET version=NULL "                       .
                        		"WHERE  version IN ("     . $currentversionList . ") "  .
                                	"AND    version NOT IN (" . $submittedList      . ")");
                       
			Database::query("DELETE FROM version "                                  .
                                	"WHERE  id IN ( "         . $currentversionList . ") "  .
                                	"AND    id NOT IN ("      . $submittedList      . ")");
		}
	}
	
	/**
	 * Set the osID
	 * This will set the operating system id.
	 * @param osId The operating system id.
	 */
	public function setOsId($osId) {
		$this->osId = $osId;
	}
}
?>
