<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include all required classes */
include_once("include/Page.class.php");
include_once("include/OS.class.php");
include_once("include/Output.class.php");

/**
 * A page to edit operating systems.
 * This class is responsible for editing operating systems.
 * @see Page
 * @see OS
 */
class EditOSPage extends Page {

	private $os;

	/**
	 * Class constructor.
	 * The class constructor for the EditOSPage class.
	 * @see OS
	 */
	public function EditOSPage() {
		/* Did the client give us the osId? */
		if(!isset($_GET['id'])) {
			Output::htmlError("Could not detect the operating system you want to edit");
		} else {
			$this->os = new OS($_GET['id']);
			
			if(!$this->os->exists()) {
				Output::htmlError("Sorry, the operating system you are looking for, does not exist!");
				unset($this->os);
			}
		}
	}

	/**
	 * Handler for HTTP GET.
	 * This function just show the os.
	 */
	public function get() {	
		if(isset($this->os)) {
			$this->os->fillWithDatabase();
			$this->showOS();
		}
	}

	/**
	 * Handler for HTTP POST.
	 * This function is used to edit and save the os.
	 */
	public function post() {

		if(isset($this->os)) {
			$this->os->fillWithPost();
			
			/* Did the user press the 'Save Operating System' button? */
			if(!empty($_POST['save'])) {
				/* Attempt to save the os */
				if($this->os->save(true))
					Output::redirect("index.php?page=OsPage");
				else
					$this->showOS();
			} else
				$this->showOS();
		}
	}

	/**
	 * Show the os in a HTML form.
	 * Shows the os, filled in with $_POST or database data.
	 */
	private function showOS() {

		Output::htmlBody("<form method=\"post\" action=\"index.php?page=EditOsPage&id=" . Util::makeFormSafe($_GET['id']) . "\">\n"		.
				 "<br>\n"														.
				 "<br>\n"														.
				 $this->os->html()													.
				 "<br>\n"														.
				 "<center>\n"														.
				 "<input type=\"submit\" name=\"save\"   value=\"Save Operating System\">\n"						.
				 "</center>\n"														.
				 "</form>\n"														.
				 "<br>\n"														.
				 "<br>\n");
	}
}
?>
