<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include all required classes */
include_once("include/Page.class.php");
include_once("include/System.class.php");
include_once("include/Output.class.php");

/**
 * A page to edit systems.
 * This class is responsible for editing and deleting systems.
 * @see Page
 * @see System
 */
class EditSystemPage extends Page {

	private $system;

	/**
	 * Class constructor.
	 * The class constructor for the EditSystemPage class.
	 * @see System
	 */
	public function EditSystemPage() {
		/* Did the client give us the system id? */
		if(!isset($_GET['id'])) {
			Output::htmlError("Could not detect the system you want to edit");
		} else {
			$this->system = new System($_GET['id']);
			
			if(!$this->system->exists()) {
				Output::htmlError("Sorry, the system you are looking for, does not exist!");
				unset($this->system);
			}
		}
	}

	/**
	 * Handler for HTTP GET.
	 * This function just show the system.
	 */
	public function get() {	
		if(isset($this->system)) {
			$this->system->fillWithDatabase();
			$this->showSystem();
		}
	}

	/**
	 * Handler for HTTP POST.
	 * This function is used to edit and save the system.
	 */
	public function post() {

		if(isset($this->system)) {
			$this->system->fillWithPost();
			
			/* Did the user press the 'Save System' button? */
			if(!empty($_POST['save'])) {
				/* Attempt to save the system */
				if($this->system->save(true))
					Output::redirect("index.php?page=SystemOverviewPage");
				else
					$this->showSystem();
			
			/* Did the user press the 'Delete System' button? */
			} else if(!empty($_POST['delete'])) {
				if($this->system->delete())
					Output::redirect("index.php?page=SystemOverviewPage");
				else
					$this->showSystem();
			} else
				$this->showSystem();
		}
	}

	/**
	 * Show the system in a HTML form.
	 * Shows the current system, filled in with $_POST or database data.
	 */
	private function showSystem() {

		Output::htmlBody("<form method=\"post\" action=\"index.php?page=EditSystemPage&id=" . Util::makeFormSafe($_GET['id']) . "\">\n"		.
				 "<br>\n"														.
				 "<br>\n"														.
				 $this->system->html()													.
				 "<br>\n"														.
				 "<center>\n"														.
				 "<input type=\"submit\" name=\"save\"   value=\"Save System\">\n"							.
				 "<input type=\"submit\" name=\"delete\" value=\"Delete System\" "							.
				  "onClick=\"return verifyDelete('" . Util::makeJavascriptSafe($this->system->getField("name")->getValue()) . "')\">\n"	.
				 "</center>\n"														.
				 "</form>\n"														.
				 "<br>\n"														.
				 "<br>\n");
	}
}
?>
