<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include all required classes */
include_once("include/Page.class.php");
include_once("include/Table.class.php");
include_once("include/Database.class.php");
include_once("include/OS.class.php");

/**
 * A page to administrate operating systems.
 * This page allows the user to add, modify and delete operating systems from/to the database.
 * @see Page
 * @see Database
 */
class OsPage {

	/**
	 * Class constructor.
	 * The class constructor.
	 * @see Page
	 * @see Database
	 */
	public function OsPage() {	
	}


	/**
	 * HTTP GET handler.
	 * This will just show an overview of operating systems.
	 * @see Page
	 * @see Database
	 */
	public function get() {
		$this->showOperatingSystems();
	}
	 
	/**
	 * HTTP POST handler.
	 * This will show the overview of operating systems, and possibly delete an operating system.
	 * @see Page
	 * @see Database
	 */
	public function post() {

		/* Reset the $_POST array pointer */
		reset($_POST);

		/* Loop all $_POST values, and see if it contains 'deleteos' */
		while(list($key, $value) = each($_POST)) {
			/* Does this $_POST value contains a delete request? */
			if(ereg("^deleteos", $key) && !empty($value)) {
			
				/* Extract the id of the OS */
				$osId = substr($key, 8);

				/* Remove the os */
				$os = new OS($osId);
				$os->delete();
			}
		}
		$this->showOperatingSystems();
	}

	/**
	 * Show a list of operating systems.
	 * This function shows the current list of operating systems in the database to the user.
	 * @see Database
	 */
	public function showOperatingSystems() {

		/* First we query the database for a list of all current operating systems */
		if(($oss = Database::query("SELECT s.id, s.name FROM os s ORDER BY s.name"))) {

			/* Create a new Table object to output the Operating Systems table */
			$osTable = new Table("500");
	
			/* Add appropriate Columns to $osTable */
			$osTable->addColumn("Operating System");
			$osTable->addColumn("", 100);

			/* Now we loop all the operating systems from $oss, and add them to osTable */
			while(($os = mysql_fetch_array($oss))) {
				$os = Util::makeFormSafe($os);
				/* Operating System */
				$osTable->addRow("<a href=\"index.php?page=EditOsPage&amp;id=" . $os['id'] . "\">" . $os['name'] . "</a>");
				/* Delete button */
				$osTable->addRow("<input type=\"submit\" name=\"deleteos" . $os['id'] . "\" value=\"Delete\" " .
						 "onClick=\"return verifyDelete('" . Util::makeJavascriptSafe($os['name']) . "')\">");
			}

			/* If no entries are in the database, inform the visitor about this */
			if($osTable->isEmpty()) {
				$osTable->addRow("There are no operating systems currently in the database.", "100", "center", "middle");
				$osTable->addRow("");
			}
		
			/* Also include a 'Create' button to let the user create a new operating system */
			$osTable->addRow("<br><input type=\"text\"   name=\"newos\"    value=\"\" size=\"40\"><br><br>", "", "center");
			$osTable->addRow("<br><input type=\"button\" name=\"createos\" value=\"Create\" " .
					 " onClick=\"document.location='index.php?page=NewOsPage&amp;name=' + document.form1.newos.value\"><br><br>", "", "center");
	
			/* Now we output the final table */
			Output::htmlBody("<br>"										.
					 "<br>"										.
					 "<form method=\"post\" name=\"form1\" action=\"index.php?page=OsPage\">"	.
					 $osTable->html()								.
					 "</form>"									.
					 "<br>");
		}
	}
}
?>
