<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include all required classes */
include_once("include/Page.class.php");
include_once("include/Table.class.php");
include_once("include/config.php");

/**
 * Page for changing settings.
 * With this page, you can change all current settings saved in include/config.php
 * @see Page
 */
class SettingsPage extends Page {

	private $settings;

	/**
	 * Class constructor.
	 * This is the class constructor.
	 */
	public function SettingsPage() {
		global $mysql_host, $mysql_db, $mysql_user, $refresh_rate;
		$this->settings = array_merge(array("hostname" => $mysql_host, "database" => $mysql_db, "username" => $mysql_user, "password" => "", "refresh_rate" => $refresh_rate), $_POST);
	}
	
	/**
	 * Handler for HTTP GET.
	 * This function shows the current settings.
	 */
	public function get() {
		$this->showSettings();
	}

	/**
	 * Handler for HTTP POST
	 * This function shows the current settings, from $_POST.
	 */
	public function post() {
		/* Check if the user pressed the save button */
		if(!empty($_POST['save'])) {
			
			/* Verify that all fields are filled in */
			while(list($key, $value) = each($this->settings)) {
				if(empty($value)) {
					Output::htmlError("You must fill in all fields", "Error", false);
					return $this->showSettings();
				}
			}
			
			/* Attempt to save settings */
			if($this->saveSettings()) {
				Output::redirect("index.php?page=SystemOverviewPage");
				return;
			}
		}	
		/* Per default show current settings */
		return $this->showSettings();
	}
	
	/**
	 * Save settings.
	 * Save the current settings to include/config.php.
	 * @return a boolean indicating success or failure.
	 */
	private function saveSettings() {

		/* The refresh rate must be at least ten seconds. */
		if(intval($this->settings['refresh_rate']) <= 9) {
			Output::htmlError("The refresh rate must be at least 10 seconds", "Error", false);
			return false;
		} else {
			/* Force refresh_rate to be an int */
			$this->settings['refresh_rate'] = intval($this->settings['refresh_rate']);
		
			/* Filter input */
			while(list($key, $value) = each($this->settings)) {
				$this->settings[$key] = addslashes(stripslashes(Util::stripNewLine($value)));
			}
			$this->settings = Util::makeFormSafe($this->settings);
	
			if(!(@$fp = fopen("include/config.php", "w"))) {
				Output::htmlError("Failed to open include/config.php in writing mode. Please verify that I have permission to write to the file.", "Error", false);
			} else {
				if(fwrite($fp, 
					"<?php\n" .
					"\$mysql_host = '"	. $this->settings['hostname']		. "';\n" .
					"\$mysql_db   = '"	. $this->settings['database']		. "';\n" .
					"\$mysql_user = '"	. $this->settings['username']		. "';\n" .
					"\$mysql_pass = '"	. $this->settings['password']		. "';\n" .
					"\$refresh_rate = '"	. $this->settings['refresh_rate']	. "';\n" .
					"?>") === false)
				{
					Output::htmlError("Failed to write to include/config.php", "Error", false);
					return false;
				} else
					fclose($fp);
			}
		}
		/* Success */
		return true;
	}

	/**
	 * Show the current settings.
	 * Show the current settings in a HTML form.
	 */
	function showSettings() {
		/* Create a new Table object to output the settings */
		$settingsTable = new Table("500", "center", "normaltable", false);
		$settingsTable->setTitle("Settings");
	
		/* Add appropriate Columns to $settingsTable */
		$settingsTable->addColumn("", 200);
		$settingsTable->addColumn("");

		/* Fill in the table */
		$settingsTable->addRow("MySQL hostname:", "30", "left");
		$settingsTable->addRow("<input type=\"text\"     name=\"hostname\" value=\"" . Util::makeFormSafe($this->settings['hostname']) . "\">", "30", "left");
		$settingsTable->addRow("MySQL database:", "30", "left");
		$settingsTable->addRow("<input type=\"text\"     name=\"database\" value=\"" . Util::makeFormSafe($this->settings['database']) . "\">", "30", "left");
		$settingsTable->addRow("MySQL username:", "30", "left");
		$settingsTable->addRow("<input type=\"text\"     name=\"username\" value=\"" . Util::makeFormSafe($this->settings['username']) . "\">", "30", "left");
		$settingsTable->addRow("MySQL password:", "30", "left");
		$settingsTable->addRow("<input type=\"password\" name=\"password\" value=\"" . Util::makeFormSafe($this->settings['password']) . "\">", "30", "left");
		$settingsTable->addRow("");
		$settingsTable->addRow("");
		$settingsTable->addRow("Overview refresh rate:", "30", "left");
		$settingsTable->addRow("<input type=\"text\" name=\"refresh_rate\" value=\"" . Util::makeFormSafe($this->settings['refresh_rate']) . "\" size=\"4\">&nbsp;&nbsp;&nbsp;seconds",
					"30", "left");
		$settingsTable->addRow("");
		$settingsTable->addRow("");
	
		/* Now we output the final table */
		Output::htmlBody("<br>"										.
				 "<br>"										.
				 "<form method=\"post\" name=\"form1\" action=\"index.php?page=SettingsPage\">"	.
				 $settingsTable->html()								.
				 "<br>"										.
				 "<center>"									.
				 "<input type=\"submit\" name=\"save\" value=\"Save Changes\">"			.
				 "</center>"									.
				 "</form>"									.
				 "<br>");
	}
}
?>
