<?php
/*
 * Copyright (C) 2007 Niek Linnenbank <niek.linnenbank@planet.nl>
 */

/* Make sure we are not directly invoked */
if(!defined("INDEX"))
	die();

/* Include all required classes */
include_once("include/Page.class.php");
include_once("include/Table.class.php");
include_once("include/Database.class.php");
include_once("include/config.php");

/**
 * An overview of systems.
 * This class is responsible for showing an overview of systems.
 * @see EditSystemPage
 */
class SystemOverviewPage extends Page {

	private $systems;
	private $orderBy;
	private $orderType;
	private $selectedGroup;
	private $searchGroup;
	private $searchKeyword;

	/* All allowed values for $_GET['order'] */
	private	$orderValues = array(	"name"    => "s.name",
					"user"    => "u.name",
					"os"      => "o.name",
					"version" => "v.name",
					"special" => "p.name",
					"comment" => "s.comments");
	/**
	 * Class constructor.
	 * The class constructor.
	 */
	public function SystemOverviewPage() {
	
		global $refresh_rate;
	
		/* This page must be auto-refreshed every $refresh_rate seconds */
		Output::htmlHeader("<meta http-equiv=\"Refresh\" content=\"" . Util::makeFormSafe($refresh_rate) . "\">");
	
		/* See if $_GET['order'] is set to an allowed value, and set it if it's allowed. */
		if(!empty($_GET['order']) && array_key_exists($_GET['order'], $this->orderValues))
			$this->orderBy = $_GET['order'];
		else
			$this->orderBy = "name";

		/* If $_GET['desc'] is set, reverse the order of sorting */
		if(isset($_GET['desc']))
			$this->orderType = "DESC";
		else
			$this->orderType = "ASC";

		/* Determine the currently selected group */
		if(!empty($_GET['group'])) {
			$this->selectedGroup = Util::makeFormSafe($_GET['group']);
		} else {
			$selectedGroupArray = Database::queryToArray("SELECT id FROM `group` WHERE isdefault=true LIMIT 1", false);
			$this->selectedGroup = $selectedGroupArray[0];
		}

		/* Fill in the searchGroup field, which can restrict queries to a particular group only */
		if($this->selectedGroup == "all")
			$this->searchGroup = " IS NOT NULL";
		else
			$this->searchGroup = " ='" . Util::makeSqlSafe($this->selectedGroup) . "'";

		/* We can search for systems which have $searchKeyword in their name, hardware, user, version, special or comment field */
		if(!empty($_GET['keyword'])) {
			$this->searchKeyword = $_GET['keyword'];
		} else {
			$this->searchKeyword = "";
		}

		/* Query the database for all systems, it's user, version and os name and specialities. Also order by $order and $orderType */
		$this->systems = Database::query("SELECT	s.id as id,"									.
						 "		s.host as host,"								.
						 "		s.ilo as ilo,"									.
						 "		s.dec as `dec`,"									.
						 "		s.decport as decport,"								.
						 "		s.console as console,"								.
						 "		s.name as name,"								.
						 "		s.hardware as hardware,"							.
						 "		u.name as username,"								.
						 "		v.name as versionname,"								.
						 "		v.os as versionos,"								.
						 "		o.name as osname,"								.
						 "		p.name as specialname,"								.
						 "		s.comments as comments,"							.
						 "		IF(" 	. Util::makeSqlSafe($this->orderValues[$this->orderBy]) . " IS NULL OR " 		.
						 			  Util::makeSqlSafe($this->orderValues[$this->orderBy]) . "='', 1, 0) as isnull "	.
						 "FROM		system s "									.
						 "LEFT JOIN	user u ON s.user=u.id "								.
						 "LEFT JOIN	version v ON s.version=v.id "							.
						 "LEFT JOIN	os o ON v.os=o.id "								.
						 "LEFT JOIN	special p ON s.special=p.id "							.
						 "WHERE		s.`group` " 	. $this->searchGroup . " "					.
						 "AND (		s.name		LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%' "	.
						 "OR		s.hardware	LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%' "	.
						 "OR		u.name		LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%' "	.
						 "OR		v.name		LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%' "	.
						 "OR		o.name		LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%' "	.
						 "OR		p.name		LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%' "	.
						 "OR		s.comments	LIKE '%" . Util::makeSqlSafe($this->searchKeyword) . "%') "	.
						 "ORDER BY	isnull ASC, " . Util::makeSqlSafe($this->orderValues[$this->orderBy]) . " " . Util::makeSqlSafe($this->orderType)
		);
	}
	
	/**
	 * Handler for HTTP GET.
	 * This function actually shows the system overview.
	 * @see Page
	 * @see Table
	 */
	public function get() {	
	
		/* Create a new Table object to output the overview table */
		$overviewTable = new Table("97%");
		
		/* Add appropriate Columns to overviewTable */
		$overviewTable->addColumn("", 60);
	
		$overviewColumns = array(array("System", 150, "name"),
					 array("Administrated by", 150, "user"),
					 array("Operating System", 150, "os"),
					 array("Version", 200, "version"),
					 array("Speciality", 150, "special"),
					 array("Comments", "*", "comment"));
					 
		/* Each column is a link, containing the appropriate &order= value, to sort the overview on this column */
		for($i = 0; $i < count($overviewColumns); $i++) {
			
			$column = "<a href=\"index.php?page=SystemOverviewPage&amp;keyword=" . Util::makeFormSafe($this->searchKeyword) . 
				  "&amp;group=" . $this->selectedGroup . "&amp;order=" . $overviewColumns[$i][2];
		
			if($this->orderBy == $overviewColumns[$i][2]) {
				if($this->orderType == "ASC")
					$column .= "&amp;desc\">" . $overviewColumns[$i][0] . "</a> <img src=\"images/arrow_down.gif\" border=\"0\" alt=\"\">";
				else
					$column .= "\">" . $overviewColumns[$i][0] . "</a> <img src=\"images/arrow_up.gif\" border=\"0\" alt=\"\">";
		
			} else 
				$column .= "\">" . $overviewColumns[$i][0] . "</a>";
		
			$overviewTable->addColumn($column, $overviewColumns[$i][1]);
		}

		/* Now we loop all the systems from the database, and add them to overviewTable */
		while(($system = mysql_fetch_array($this->systems))) {
		
			/* escape all html tags in the $system data */
			$system = Util::makeFormSafe($system);
		
			$overviewTable->addRow($this->getShortcutIcons($system), "*", "left");
			/* System */
			$overviewTable->addRow(	"<a href=\"index.php?page=EditSystemPage&amp;id=" . $system['id'] . "\"" . 
						" onMouseOver=\"showFloatMessageBox(event,'" . Util::makeJavascriptSafe($system['hardware']) . "')\"" .
						" onMouseOut=\"hideFloatMessageBox(event)\">" .
						$system['name'] .
						"</a>");
			/* Administrated By */
			$overviewTable->addRow($system['username']);
			/* Operating System */
			$overviewTable->addRow($system['osname']);
			/* Version */
			$overviewTable->addRow($system['versionname']);
			/* Specialities */
			$overviewTable->addRow($system['specialname']);
			/* Comments */
			$overviewTable->addRow("<div onMouseOver=\"showFloatMessageBox(event,'" . Util::makeJavascriptSafe($system['comments']) . "')\"" .
					       "     onMouseOut=\"hideFloatMessageBox(event)\">" .
					       Util::getLine($system['comments'], 0) .
					       "</div>");
		}

		/* If no entries are in the database, inform the visitor about this */
		if($overviewTable->isEmpty())
			$overviewTable->addRow("There are no systems to view", "100", "center", "middle", "7", "1");

		/*
		 * Now we define a small search form
		 */

		/* Query the database for a list of all current groups, ordered alphabetically */
		$groups = Database::queryToArray("SELECT id,name FROM `group` ORDER BY name", true);

		/* Also add an option "All groups" to the $groups array */
		array_unshift($groups, array(0 => "all", 1 => "All groups"));

		/* Construct the search table */			
		$searchTable = new Table("97%", "center", "normaltable", false);
		$searchTable->addColumn();

		$searchTable->addRow(	"<form name=\"searchform\" method=\"get\" style=\"margin: 0px; padding: 0px;\" action=\"\">\n"					.
					"Search: "															.
					"&nbsp;&nbsp;&nbsp;&nbsp;<input type=\"text\"   name=\"keyword\" value=\"" . Util::makeFormSafe($this->searchKeyword) . "\">"	.
					"&nbsp;&nbsp;&nbsp;&nbsp;" . ComboBox::createFromArray("group", $this->selectedGroup, $groups)					.
					"&nbsp;&nbsp;&nbsp;&nbsp;<input type=\"submit\" name=\"search\" value=\"Search\">"						.
					"<br>"																.
					"</form>",
					"50", "center", "middle", "1", "1", "equalrow");
	
		/* Now we output the final page */
		Output::htmlBody("<br><br>" . $searchTable->html() . "<br>" . $overviewTable->html() . "<br>");
	}
	
	/**
	 * Get shortcut icons.
	 * This function returns the HTML for the shortcut icons.
	 * @return HTML containing shorcut icons.
	 */
	 public function getShortcutIcons($system) {
	 
	 	$html  = "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\"><tr>";
		$html .= "<td width=\"20\" height=\"18\" align=\"center\">";

		/* SSH */
		if(!empty($system['host']))
			$html .= "<a href=\"ssh://" . Util::makeFormSafe($system['host']) . "\"><img border=\"0\" src=\"images/ssh.gif\" alt=\"Secure SHell\"></a>";

		$html .= "</td>";
		$html .= "<td width=\"20\" height=\"18\" align=\"center\">";

		/* VNC */
		if(!empty($system['host']))
			$html .= "<a href=\"vnc://" . Util::makeFormSafe($system['host']) . "\"><img border=\"0\" src=\"images/vnc.gif\" alt=\"Virtual Network Computing\"></a>";
			
		$html .= "</td>";
		$html .= "<td width=\"20\" height=\"18\" align=\"center\">";
		
		/* ILO */
		if(!empty($system['ilo']))
			$html .= "<a href=\"http://" . Util::makeFormSafe($system['ilo']) . "\" target=\"_blank\">" .
				 "<img border=\"0\" src=\"images/terminal.gif\" alt=\"Hewlett Packet Integrated Lights Out\"></a>";
		
		/* DEC */
		else if(!empty($system['dec']) && !empty($system['decport']))
			$html .= "<a href=\"telnet://" . Util::makeFormSafe($system['dec']) . ":" . Util::makeFormSafe($system['decport']) . "\" target=\"_blank\">" .
				 "<img border=\"0\" src=\"images/terminal.gif\" alt=\"Hewlett Packet Digital Entertainment Center\"></a>";
		
		/* Console */
		else if(!empty($system['console']))
			$html .= "<a href=\"console://" . Util::makeFormSafe($system['console']) . "\" target=\"_blank\">" .
				 "<img border=\"0\" src=\"images/terminal.gif\" alt=\"Hewlett Packet Console\"></a>";
		
		$html .= "</td>";
		$html .= "</tr></table>";
		
		return $html;
	}
}
?>
